function get_tex(f,cmd,ar,varargin)

% ----------------------------------------------------------------------- %
% GET_TEX(f,cmd,ar)
%   f   file to work on (str)
%   cmd cmd string to look for (str)
%   ar  number of arguments to cmd (num)
% EXAMPLES
%   >> get_tex('test.tex','\solveit',3)
%   >> get_tex('test.tex','\defit',2)
%   Will put,
%
%     \fndnum{1}
%     \solveit{ ... }{ ... }{ ... }
%     ...
%
%   and
%
%     \fndnum{1}
%     \defit{ ... }{ ... }
%     ...
%
%   into output file 'out.tex' respectively.
% OPTION
%   (...,lc) enter a number to specify a global identifier number for
%     this file, to be pre-pended to each matching id number.
% ----------------------------------------------------------------------- %

% deal with varargin
glb = char([]);
if nargin > 3
	glb = [int2str(varargin{1}) '.'];
end

% get file data
fid = fopen(f);
F = [char(fread(fid))]';
fclose(fid);
n_st = length(F);

% find instances of CMD
hits = strfind(F,cmd);
n_ht = length(hits);
l_cm = length(cmd);

% check that we have a hit
fid = fopen('out.tex','w');	% prepare for output
if isempty(hits)
	fprintf(fid,'\n\\noexmpls\n\n');
	disp(sprintf('Didn''t find an instance of %s in #%s.',cmd,glb));
	fclose(fid);
	return
end

% for each, get string up to end of arg `{...}' instances
for n = 1:n_ht
	h = hits(n);
	s = F(h+l_cm:n_st);			% string to work on (end_cmd --> end)
	rgstr = zeros(1,length(s));
	op_ids = strfind(s,'{');
	cl_ids = strfind(s,'}');
	rgstr(op_ids) = +1;
	rgstr(cl_ids) = -1;
	R = cumsum(rgstr);			% get cumulative sum
	fR = find(R==0);			% points where scoping closes
	try
	e = fR(ar);					% AR argument close
	catch
	keyboard
	end
	tmp(n) = {s(1:e)};
end

% put into file
for n = 1:n_ht
	fprintf(fid,'\n\\fndnum{%s%d}%s%s\n\n',glb,n,cmd,char(tmp(n)));
end
fclose(fid);



