function solveit(v,varargin)

% SOLVEIT
%   An automated Lecture Example/Solutions document preparation
%   script. Please read README for more details.
% AUTHOR
%   (c) S.Angus (2005), UNSW
% INPUT
%   (V) A vector of lectures to search.
% OPTIONS
%   (...,D) where D=1 switches on `accessibility' mode.
% EXAMPLE
%     >> solveit(2:6)
%   will compile examples with answers from lectures numbered
%   2 to 6.
% OUTPUT
%    - solve.tex
% See also INT2STRL FWRITE GET_TEX

% NOTES:
%   o. deals with lecture hierarchy up [1...99]

% // add header
D = 0;
if nargin > 1, D = varargin{1}; end

if D									% accessibility mode
	out_txt = fileread('solveit-a.head');
else
	out_txt = fileread('solveit.head');
end

% // for all lectures in input vector V
for lc = v
	% setup for this file
	lc_s = int2strL(lc,2);
	sep_txt = sprintf('\\ltitle{Lecture %d}\n\n',lc);
	% load new file
	new_file_name = sprintf('../%s/%s.tex',lc_s,lc_s);
	% get solveit parts and arguments of text only
	get_tex(new_file_name,'\solveit',3,lc);		% makes file 'out.tex'
	% augment appropriately
	new_txt = fileread('out.tex');
	out_txt = cat(2,out_txt,sep_txt);		% add separator
	out_txt = cat(2,out_txt,new_txt);		% add new lecture content
end

% // add footer
if D									% accessibility mode
	footer_txt = fileread('solveit-a.foot');
else
	footer_txt = fileread('solveit.foot');
end
out_txt = cat(2,out_txt,footer_txt);

% // output OUT_TXT to a file
fid = fopen('solve.tex','w+');
count = fwrite(fid,out_txt);
fclose(fid);

